# dpeeg

Dpeeg provides a complete workflow for deep learning decoding EEG tasks, including basic datasets (datasets 
can be easily customized), basic network models, model training, and detailed training results storage methods.

Each module in dpeeg is decoupled as much as possible to facilitate the use of separate modules. 

# Usage

```Shell
pip install dpeeg
```